==> mongo-cxx-driver_4.0.0.orig.tar.gz: mongo-cxx-driver-4.0.0/examples/api/mongocxx/examples/collections/index_views/create.cpp <==
// Copyright 2009-present MongoDB, Inc.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

#include <algorithm>

#include <bsoncxx/json.hpp>

#include <mongocxx/client.hpp>
#include <mongocxx/collection.hpp>
#include <mongocxx/database.hpp>
#include <mongocxx/index_model.hpp>
#include <mongocxx/index_view.hpp>
#include <mongocxx/uri.hpp>

#include <examples/api/concern.hh>
#include <examples/api/db_lock.hh>
#include <examples/api/runner.hh>
#include <examples/macros.hh>

namespace {

// [Example]
void example(mongocxx::index_view indexes) {
    // Basic usage.
    {
        auto result_opt = indexes.create_one(bsoncxx::from_json(R"({"x": 1})"));

        EXPECT(result_opt);
        EXPECT(result_opt->compare("x_1") == 0);
    }

    // Index model.
    {
        auto result_opt =
            indexes.create_one(mongocxx::index_model{bsoncxx::from_json(R"({"y": 1})")});

        EXPECT(result_opt);
        EXPECT(result_opt->compare("y_1") == 0);
    }
}
// [Example]

}  // namespace

RUNNER_REGISTER_COMPONENT_FOR_SINGLE() {
    mongocxx::client client{mongocxx::uri{}};

    {
        db_lock guard{client, EXAMPLES_COMPONENT_NAME_STR};

        auto coll = set_rw_concern_majority(guard.get().create_collection("coll"));

        auto count_indexes = [&coll] {
            auto cursor = coll.list_indexes();

            return std::distance(cursor.begin(), cursor.end());
        };

        EXPECT(count_indexes() == 1);  // _id_

        example(coll.indexes());

        EXPECT(count_indexes() == 3);  // _id_, x_1, y_1
    }
}

==> mongo-cxx-driver_4.1.4.orig.tar.gz: mongo-cxx-driver-4.1.4/examples/api/mongocxx/examples/collections/index_views/create.cpp <==
// Copyright 2009-present MongoDB, Inc.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

#include <algorithm>

#include <bsoncxx/json.hpp>

#include <mongocxx/client.hpp>
#include <mongocxx/collection.hpp>
#include <mongocxx/database.hpp>
#include <mongocxx/index_model.hpp>
#include <mongocxx/index_view.hpp>
#include <mongocxx/uri.hpp>

#include <examples/api/concern.hh>
#include <examples/api/db_lock.hh>
#include <examples/api/runner.hh>
#include <examples/macros.hh>

namespace {

// [Example]
void example(mongocxx::index_view indexes) {
    // Basic usage.
    {
        auto result_opt = indexes.create_one(bsoncxx::from_json(R"({"x": 1})"));

        EXPECT(result_opt);
        EXPECT(result_opt->compare("x_1") == 0);
    }

    // Index model.
    {
        auto result_opt = indexes.create_one(mongocxx::index_model{bsoncxx::from_json(R"({"y": 1})")});

        EXPECT(result_opt);
        EXPECT(result_opt->compare("y_1") == 0);
    }
}
// [Example]

} // namespace

RUNNER_REGISTER_COMPONENT_FOR_SINGLE() {
    mongocxx::client client{mongocxx::uri{}};

    {
        db_lock guard{client, EXAMPLES_COMPONENT_NAME_STR};

        auto coll = set_rw_concern_majority(guard.get().create_collection("coll"));

        auto count_indexes = [&coll] {
            auto cursor = coll.list_indexes();

            return std::distance(cursor.begin(), cursor.end());
        };

        EXPECT(count_indexes() == 1); // _id_

        example(coll.indexes());

        EXPECT(count_indexes() == 3); // _id_, x_1, y_1
    }
}
